.. Copyright (C) 2018 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.ansible`` role can be used to install Ansible on a Debian or
Ubuntu host. Ansible will be installed either from the OS repositories, from
Ansible upstream APT repository, or using a locally built ``.deb`` package.
